@@ -1,4 +1,3 @@
-
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
 # License as published by the Free Software Foundation; either
@@ -28,10 +27,10 @@ linearInterp <-
            yo = seq(min(y), max(y), length = gridPoints))
   {
     # A function implemented by Diethelm Wuertz
-    
+
     # Description:
     #   Interpolates Linearly Irregularly Distributed Data Points
-    
+
     # Arguments:
     #   x, y, z - either three numeric vectors of equal length or if
     #       y and z are NULL, a list with entries x, y, a, or named
@@ -39,47 +38,49 @@ linearInterp <-
     #       the third column.
     #   gridPoints - number of grid points in x and y direction.
     #   xo, yo, a sequence of data points spanning the grid
-    
+
     # Note:
     #   Extrapolation is not possible in the case of linear interpolation.
-    
+
     # Value:
     #   A list with three elements, $x and $y which are vectors of length
     #   'gridPoints' and $z which is a matrix of size 'gridPoints^2'.
-    
+
     # Requirements:
     #   akima Builtin Fortran Code.
-    
+
     # Example:
     #   set.seed(1953)
     #   x = runif(999)-0.5; y = runif(999)-0.5; z = cos(2*pi*(x^2+y^2))
     #   ans = linearInterp(x, y, z)
     #   persp(ans, theta = -50, phi = 30, col = "steelblue")
-    
+
     # Note:
     #   Uses Fortran akima Builtin
-    
+
     # FUNCTION:
-    
-    if (!require(akima, quietly = TRUE))
-      stop("\n -- Package akima not available -- \n\n")
-    
+
+    if (!requireNamespace("akima", quietly = TRUE))
+      stop("Needs Package 'akima' which is not auto-installed because of a different licence\n")
+
     # Arguments:
-    if (is.list(x)) x = matrix(unlist(x), ncol = 3)
-    if (is.data.frame(x)) x = as.matrix.data.frame(x)
+    if (is.data.frame(x))
+      x <- as.matrix.data.frame(x)
+    else if (is.list(x))
+      x <- matrix(unlist(x), ncol = 3)
     if (is.matrix(x)) {
       z = x[, 3]
       y = x[, 2]
       x = x[, 1]
     }
-    
+
     # Interpolation:
-    ans <- akima::interp.old(x, y, z, xo, yo, ncp = 0, extrap = FALSE,
-                             duplicate = "median", dupfun = NULL)
+    ans <- akima::interp(x, y, z, xo, yo, linear = TRUE, extrap = FALSE,
+                         duplicate = "median", dupfun = NULL)
     colnames(ans$z) <- as.character(signif(ans$x, round(log(gridPoints), 0)))
     rownames(ans$z) <- as.character(signif(ans$y, round(log(gridPoints), 0)))
     class(ans) <- "gridData"
-    
+
     # Return Value:
     ans
   }
@@ -92,10 +93,10 @@ linearInterpp <-
   function(x, y = NULL, z = NULL, xo, yo)
   {
     # A function implemented by Diethelm Wuertz
-    
+
     # Description:
     #   Interpolates Linearly Irregularly Distributed Data Points
-    
+
     # Arguments:
     #   x, y, z - either three numeric vectors of equal length or if
     #       y and z are NULL, a list with entries x, y, a, or named
@@ -103,48 +104,48 @@ linearInterpp <-
     #       the third column.
     #   gridPoints - number of grid points in x and y direction.
     #   xo, yo, a sequence of data points for pointwise interpolation
-    
+
     # Note:
     #   Extrapolation is not possible in the case of linear interpolation.
-    
+
     # Value:
     #   A list with three elements, $x and $y which are vectors of length
     #   'gridPoints' and $z which is a matrix of size 'gridPoints^2'.
-    
+
     # Requirements:
     #   akima Builtin Fortran Code.
-    
+
     # Example:
     #   set.seed(1953)
     #   x = runif(999)-0.5; y = runif(999)-0.5; z = cos(2*pi*(x^2+y^2))
     #   ans = linearInterpp(x, y, z, c(mean(x), 0, 100), c(mean(y), 0, 100))
     #   persp(ans, theta = -50, phi = 30, col = "steelblue")
-    
+
     # Note:
     #   Uses Fortran akima Builtin
-    
+
     # FUNCTION:
-    
-    if (!require(akima, quietly = TRUE))
-      stop("\n -- Package akima not available -- \n\n")
-    
+
+    if (!requireNamespace("akima", quietly = TRUE))
+      stop("Needs Package 'akima' which is not auto-installed because of a different licence\n")
+
     # Arguments:
-    if (is.list(x)) x = matrix(unlist(x), ncol = 3)
-    if (is.data.frame(x)) x = as.matrix.data.frame(x)
+    if (is.data.frame(x))
+      x <- as.matrix.data.frame(x)
+    else if (is.list(x))
+      x <- matrix(unlist(x), ncol = 3)
     if (is.matrix(x)) {
       z = x[, 3]
       y = x[, 2]
       x = x[, 1]
     }
-    
+
     # Interpolation:
-    interpp.old <- eval(parse(text=paste0("akima",":::","interpp.old")))
-    ans <- interpp.old(x, y, z, xo, yo, ncp = 0, extrap = FALSE,
-                       duplicate = "median", dupfun = NULL)
-    ans <- data.frame(x = ans$x, y = ans$y, z = ans$z)
-    
-    # Return Value:
-    ans
+    interpp <- eval(parse(text=paste0("akima",":::","interpp")))
+    ans <- interpp(x, y, z, xo, yo, linear = TRUE, extrap = FALSE,
+                   duplicate = "median", dupfun = NULL)
+    ## Return
+    data.frame(x = ans$x, y = ans$y, z = ans$z)
   }
 
 
