@@ -212,23 +212,22 @@ function(x, title = NULL, description = NULL)
 # ------------------------------------------------------------------------------
 
 
-.skewness.test <-
-function(x)
+.skewness.test <- function(x)
 {
     # Internal Function for D'Agostino Normality Test:
 
     # Note:
     #   D'Agostino Test
     #   http://adela.karlin.mff.cuni.cz/~klaster/vyuka/
-    #   Materiेly pro cvicen, kterे byla v labu, jsou zde: cv01.txt,
+    #   Materi???ly pro cvicen????, kter??? byla v labu, jsou zde: cv01.txt,
     #   cv02.txt, cv03.txt, cv05.txt, cv06.txt, data maths, police a
-    #   vysky a makro dagost.r. Vber nejakch prkladu ze cvicen je
+    #   vysky a makro dagost.r. V????ber nejak????ch pr????kladu ze cvicen???? je
     #   tady.
-    #   Program R lze zdarma (GNU General Public Licence) stेhnout z
-    #   www.r-project.org. Alespon k letm़mu nahl़dnut doporucuji t़
-    #   minimanuेl An Introduction to R, kter roste tamt़. Dal
-    #   materiेly vcetne dvou zacेtecnickch prrucek najdete na
-    #   strेnkेch Dr. Kulicha.
+    #   Program R lze zdarma (GNU General Public Licence) st???hnout z
+    #   www.r-project.org. Alespon k letm???mu nahl???dnut???? doporucuji t????
+    #   minimanu??/l An Introduction to R, kter???? roste tamt????. Dal?????
+    #   materi???ly vcetne dvou zac???tecnick????ch pr????rucek najdete na
+    #   str???nk???ch Dr. Kulicha.
 
     # FUNCTION:
 
